@@ -32,11 +32,11 @@ class MobileShellSettings : public QObject
     // status bar
     Q_PROPERTY(bool dateInStatusBar READ dateInStatusBar WRITE setDateInStatusBar NOTIFY dateInStatusBarChanged)
     Q_PROPERTY(float statusBarScaleFactor READ statusBarScaleFactor WRITE setStatusBarScaleFactor NOTIFY statusBarScaleFactorChanged)
+    Q_PROPERTY(bool showBatteryPercentage READ showBatteryPercentage WRITE setShowBatteryPercentage NOTIFY showBatteryPercentageChanged)
 
     // navigation panel
     Q_PROPERTY(bool navigationPanelEnabled READ navigationPanelEnabled WRITE setNavigationPanelEnabled NOTIFY navigationPanelEnabledChanged)
-    Q_PROPERTY(bool alwaysShowKeyboardToggleOnNavigationPanel READ alwaysShowKeyboardToggleOnNavigationPanel WRITE setAlwaysShowKeyboardToggleOnNavigationPanel
-                   NOTIFY alwaysShowKeyboardToggleOnNavigationPanelChanged)
+    Q_PROPERTY(bool alwaysShowKeyboardToggleOnNavigationPanel READ alwaysShowKeyboardToggleOnNavigationPanel WRITE setAlwaysShowKeyboardToggleOnNavigationPanel NOTIFY alwaysShowKeyboardToggleOnNavigationPanelChanged)
 
     // action drawer
     Q_PROPERTY(ActionDrawerMode actionDrawerTopLeftMode READ actionDrawerTopLeftMode WRITE setActionDrawerTopLeftMode NOTIFY actionDrawerTopLeftModeChanged)
@@ -45,9 +45,16 @@ class MobileShellSettings : public QObject
     // convergence mode
     Q_PROPERTY(bool convergenceModeEnabled READ convergenceModeEnabled WRITE setConvergenceModeEnabled NOTIFY convergenceModeEnabledChanged)
 
+    // Auto Hide Panels
+    Q_PROPERTY(bool autoHidePanelsEnabled READ autoHidePanelsEnabled WRITE setAutoHidePanelsEnabled NOTIFY autoHidePanelsEnabledChanged)
+
     // logout dialog
     Q_PROPERTY(bool allowLogout READ allowLogout READ allowLogout NOTIFY allowLogoutChanged)
 
+    // locksreen shortcut icons
+    Q_PROPERTY(LockscreenButtonAction lockscreenLeftButtonAction READ lockscreenLeftButtonAction WRITE setLockscreenLeftButtonAction NOTIFY lockscreenLeftButtonActionChanged)
+    Q_PROPERTY(LockscreenButtonAction lockscreenRightButtonAction READ lockscreenRightButtonAction WRITE setLockscreenRightButtonAction NOTIFY lockscreenRightButtonActionChanged)
+
 public:
     MobileShellSettings(QObject *parent = nullptr);
 
@@ -57,6 +64,14 @@ public:
     };
     Q_ENUM(ActionDrawerMode)
 
+    enum LockscreenButtonAction {
+        None, // hide the button
+        Flashlight, // toggle flashlight/torch
+        Camera, // camera
+        OpenApp // cant be selected, no support yet
+    };
+    Q_ENUM(LockscreenButtonAction)
+
     /**
      * Get whether shell vibrations are enabled.
      */
@@ -126,6 +141,20 @@ public:
      */
     void setStatusBarScaleFactor(float statusBarScaleFactor);
 
+    /**
+     * Whether the battery percentage is shown in the status bar.
+     *
+     * If true, the percentage will be shown next to the battery in the status bar.
+     */
+    bool showBatteryPercentage() const;
+
+    /**
+     * Set whether the battery percentage is shown in the status bar.
+     *
+     * @param showBatteryPercentage Whether the battery percentage is shown in the status bar.
+     */
+    void setShowBatteryPercentage(bool showBatteryPercentage);
+
     /**
      * Whether the navigation panel is enabled.
      *
@@ -193,11 +222,47 @@ public:
      */
     void setConvergenceModeEnabled(bool enabled);
 
+    /**
+     * Whether Auto Hide Panels is enabled.
+     */
+    bool autoHidePanelsEnabled() const;
+
+    /**
+     * Set whether Auto Hide Panels is enabled.
+     *
+     * @param enabled
+     */
+    void setAutoHidePanelsEnabled(bool enabled);
+
     /**
      * Whether logout button is shown in the logout/shutdown dialog.
      */
     bool allowLogout() const;
 
+    /**
+     * The action of the left lock screen shortcut
+     */
+    LockscreenButtonAction lockscreenLeftButtonAction() const;
+
+    /**
+     * Set the action of the left lock screen shortcut
+     *
+     * @param action
+     */
+    void setLockscreenLeftButtonAction(LockscreenButtonAction action);
+
+    /**
+     * The action of the right lock screen shortcut
+     */
+    LockscreenButtonAction lockscreenRightButtonAction() const;
+
+    /**
+     * Set the action of the right lock screen shortcut
+     *
+     * @param action
+     */
+    void setLockscreenRightButtonAction(LockscreenButtonAction action);
+
 Q_SIGNALS:
     void vibrationsEnabledChanged();
     void vibrationDurationChanged();
@@ -207,11 +272,15 @@ Q_SIGNALS:
     void animationsEnabledChanged();
     void dateInStatusBarChanged();
     void statusBarScaleFactorChanged();
+    void showBatteryPercentageChanged();
     void taskSwitcherPreviewsEnabledChanged();
     void actionDrawerTopLeftModeChanged();
     void actionDrawerTopRightModeChanged();
     void convergenceModeEnabledChanged();
+    void autoHidePanelsEnabledChanged();
     void allowLogoutChanged();
+    void lockscreenLeftButtonActionChanged();
+    void lockscreenRightButtonActionChanged();
 
 private:
     void updateNavigationBarsInPlasma(bool navigationPanelEnabled);
